==> 0.0.5.tar.gz: android/src/main/kotlin/com/simingtang/smt_face_ml_kit/FaceAnalyzer.kt <==
package com.simingtang.smt_face_ml_kit

import androidx.camera.core.ImageAnalysis
import androidx.camera.core.ImageProxy
import com.google.mlkit.vision.common.InputImage
import com.google.mlkit.vision.face.FaceDetection
import com.google.mlkit.vision.face.FaceDetector
import com.google.mlkit.vision.face.FaceDetectorOptions
import java.nio.ByteBuffer

class FaceAnalyzer : ImageAnalysis.Analyzer {

    private var detector: FaceDetector

    init {
        val realTimeOpts = FaceDetectorOptions.Builder()
            .setContourMode(FaceDetectorOptions.CONTOUR_MODE_NONE)
            .build()
        detector = FaceDetection.getClient(realTimeOpts)

    }

    private fun ByteBuffer.toByteArray(): ByteArray {
        rewind()    // Rewind the buffer to zero
        val data = ByteArray(remaining())
        get(data)   // Copy the buffer into a byte array
        return data // Return the byte array
    }

    override fun analyze(image: ImageProxy) {
        val mediaImage = image.image
        if (mediaImage != null) {
            val detectorImage = InputImage.fromMediaImage(mediaImage, image.imageInfo.rotationDegrees)
            detector.process(detectorImage)
                .addOnSuccessListener { faces ->
                    val faceData = faces.map {
                        val rectBox = it.boundingBox
                        return@map "{" +
                                "\"centerX\":${rectBox.centerX()}," +
                                "\"centerY\":${rectBox.centerY()}," +
                                "\"width\":${rectBox.width()}," +
                                "\"height\":${rectBox.height()}," +
                                "\"imageWidth\":${detectorImage.width}," +
                                "\"imageHeight\":${detectorImage.height}" +
                                "}"
                    }.toList()
                    SmtFaceMlKitPlugin.channel.invokeMethod("faceInfos", faceData)
                }
                .addOnFailureListener { e ->
                    SmtFaceMlKitPlugin.channel.invokeMethod("error", "错误信息:人脸识别错误")
                }.addOnCompleteListener {
                    image.close()
                }
        }
    }
}

==> 0.0.7.tar.gz: android/src/main/kotlin/com/simingtang/smt_face_ml_kit/FaceAnalyzer.kt <==
package com.simingtang.smt_face_ml_kit

import android.util.Log
import androidx.camera.core.ImageAnalysis
import androidx.camera.core.ImageProxy
import com.google.mlkit.vision.common.InputImage
import com.google.mlkit.vision.face.FaceDetection
import com.google.mlkit.vision.face.FaceDetector
import com.google.mlkit.vision.face.FaceDetectorOptions
import java.nio.ByteBuffer

class FaceAnalyzer : ImageAnalysis.Analyzer {

    private var detector: FaceDetector

    init {
        val realTimeOpts = FaceDetectorOptions.Builder()
            .setContourMode(FaceDetectorOptions.CONTOUR_MODE_NONE)
            .build()
        detector = FaceDetection.getClient(realTimeOpts)

    }

    private fun ByteBuffer.toByteArray(): ByteArray {
        rewind()    // Rewind the buffer to zero
        val data = ByteArray(remaining())
        get(data)   // Copy the buffer into a byte array
        return data // Return the byte array
    }

    override fun analyze(image: ImageProxy) {
        val mediaImage = image.image
        if (mediaImage != null) {
            val detectorImage = InputImage.fromMediaImage(mediaImage, image.imageInfo.rotationDegrees)
            detector.process(detectorImage)
                .addOnSuccessListener { faces ->
                    val faceData = faces.map {
                        val rectBox = it.boundingBox
                        return@map "{" +
                                "\"centerX\":${rectBox.centerX()}," +
                                "\"centerY\":${rectBox.centerY()}," +
                                "\"width\":${rectBox.width()}," +
                                "\"height\":${rectBox.height()}," +
                                "\"imageWidth\":${detectorImage.height}," +
                                "\"imageHeight\":${detectorImage.width}" +
                                "}"
                    }.toList()
                    SmtFaceMlKitPlugin.channel.invokeMethod("faceInfos", faceData)
                }
                .addOnFailureListener { e ->
                    SmtFaceMlKitPlugin.channel.invokeMethod("error", "错误信息:人脸识别错误")
                }.addOnCompleteListener {
                    image.close()
                }
        }
    }
}
